==> icons-vue-0.6.0.tgz: package/lib/chart--scatter/20.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_ChartScatter20 = {
  name: 'ChartScatter20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M30,30H4a2,2,0,0,1-2-2V2H4V28H30Z"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "10",
        "cy": "22",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "14",
        "cy": "15",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "22",
        "cy": "15",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "26",
        "cy": "6",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "14",
        "cy": "8",
        "r": "2"
      }
    }), children]);
  }
};

module.exports = virtual_ChartScatter20;

==> icons-vue-10.6.1.tgz: package/lib/chart--scatter/20.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@carbon/icon-helpers');

var virtual_ChartScatter20 = {
  name: 'ChartScatter20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M30 30H4a2 2 0 0 1-2-2V2h2v26h26z"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "10",
        "cy": "22",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "14",
        "cy": "15",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "22",
        "cy": "15",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "26",
        "cy": "6",
        "r": "2"
      }
    }), createElement('circle', {
      attrs: {
        "cx": "14",
        "cy": "8",
        "r": "2"
      }
    }), children]);
  }
};

module.exports = virtual_ChartScatter20;
